# coding: utf-8

"""
    Amber Electric Public API

    Amber is an Australian-based electricity retailer that pass through the real-time wholesale price of energy.  Because of Amber's wholesale power prices, you can save hundreds of dollars a year by automating high power devices like air-conditioners, heat pumps and pool pumps.  This Python library provides an interface to the API, allowing you to react to current and forecast prices, as well as download your historic usage.

    The version of the OpenAPI document: 2.0.0
    Contact: dev@amber.com.au
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date
from typing import List, Optional

try:

    from pydantic.v1 import BaseModel, Field, StrictStr, conlist, constr
except ImportError:

    from pydantic import BaseModel, Field, StrictStr, conlist, constr
from amberelectric.models.channel import Channel
from amberelectric.models.site_status import SiteStatus


class Site(BaseModel):
    """
    Site
    """

    id: StrictStr = Field(default=..., description="Unique Site Identifier")
    nmi: constr(strict=True, max_length=11, min_length=10) = Field(
        default=..., description="National Metering Identifier (NMI) for the site"
    )
    channels: conlist(Channel) = Field(
        default=..., description="List of channels that are readable from your meter"
    )
    network: StrictStr = Field(
        default=..., description="The name of the site's network"
    )
    status: SiteStatus = Field(...)
    active_from: Optional[date] = Field(
        default=None,
        alias="activeFrom",
        description="Date the site became active. This date will be in the future for pending sites. It may also be undefined, though if it is, contact [info@amber.com.au](mailto:info@amber.com.au) - there may be an issue with your address. Formatted as a ISO 8601 date when present.",
    )
    closed_on: Optional[date] = Field(
        default=None,
        alias="closedOn",
        description="Date the site closed. Undefined if the site is pending or active. Formatted as a ISO 8601 date when present.",
    )
    __properties = [
        "id",
        "nmi",
        "channels",
        "network",
        "status",
        "activeFrom",
        "closedOn",
    ]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Site:
        """Create an instance of Site from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in channels (list)
        _items = []
        if self.channels:
            for _item in self.channels:
                if _item:
                    _items.append(_item.to_dict())
            _dict["channels"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Site:
        """Create an instance of Site from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Site.parse_obj(obj)

        _obj = Site.parse_obj(
            {
                "id": obj.get("id"),
                "nmi": obj.get("nmi"),
                "channels": (
                    [Channel.from_dict(_item) for _item in obj.get("channels")]
                    if obj.get("channels") is not None
                    else None
                ),
                "network": obj.get("network"),
                "status": obj.get("status"),
                "active_from": obj.get("activeFrom"),
                "closed_on": obj.get("closedOn"),
            }
        )
        return _obj



# coding: utf-8

"""
    Amber Electric Public API

    Amber is an Australian-based electricity retailer that pass through the real-time wholesale price of energy.  Because of Amber's wholesale power prices, you can save hundreds of dollars a year by automating high power devices like air-conditioners, heat pumps and pool pumps.  This Python library provides an interface to the API, allowing you to react to current and forecast prices, as well as download your historic usage.

    The version of the OpenAPI document: 2.0.0
    Contact: dev@amber.com.au
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from amberelectric.api.amber_api import AmberApi  # noqa: E501


class TestAmberApi(unittest.TestCase):
    """AmberApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AmberApi()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_get_current_prices(self) -> None:
        """Test case for get_current_prices

        """
        pass

    def test_get_current_renewables(self) -> None:
        """Test case for get_current_renewables

        """
        pass

    def test_get_prices(self) -> None:
        """Test case for get_prices

        """
        pass

    def test_get_sites(self) -> None:
        """Test case for get_sites

        """
        pass

    def test_get_usage(self) -> None:
        """Test case for get_usage

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Amber Electric Public API

    Amber is an Australian-based electricity retailer that pass through the real-time wholesale price of energy.  Because of Amber's wholesale power prices, you can save hundreds of dollars a year by automating high power devices like air-conditioners, heat pumps and pool pumps.  This Python library provides an interface to the API, allowing you to react to current and forecast prices, as well as download your historic usage.

    The version of the OpenAPI document: 2.0.0
    Contact: dev@amber.com.au
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import io
import json
import logging
import re
import ssl

from urllib.parse import urlencode
import urllib3

from amberelectric.exceptions import (
    ApiException,
    UnauthorizedException,
    ForbiddenException,
    NotFoundException,
    ServiceException,
    ApiValueError,
    BadRequestException,
)


logger = logging.getLogger(__name__)

SUPPORTED_SOCKS_PROXIES = {"socks5", "socks5h", "socks4", "socks4a"}


def is_socks_proxy_url(url):
    if url is None:
        return False
    split_section = url.split("://")
    if len(split_section) < 2:
        return False
    else:
        return split_section[0].lower() in SUPPORTED_SOCKS_PROXIES


class RESTResponse(io.IOBase):

    def __init__(self, resp) -> None:
        self.urllib3_response = resp
        self.status = resp.status
        self.reason = resp.reason
        self.data = resp.data

    def getheaders(self):
        """Returns a dictionary of the response headers."""
        return self.urllib3_response.headers

    def getheader(self, name, default=None):
        """Returns a given response header."""
        return self.urllib3_response.headers.get(name, default)


class RESTClientObject:

    def __init__(self, configuration, pools_size=4, maxsize=None) -> None:
        # urllib3.PoolManager will pass all kw parameters to connectionpool
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/poolmanager.py#L75  # noqa: E501
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/connectionpool.py#L680  # noqa: E501
        # maxsize is the number of requests to host that are allowed in parallel  # noqa: E501
        # Custom SSL certificates and client certificates: http://urllib3.readthedocs.io/en/latest/advanced-usage.html  # noqa: E501

        # cert_reqs
        if configuration.verify_ssl:
            cert_reqs = ssl.CERT_REQUIRED
        else:
            cert_reqs = ssl.CERT_NONE

        addition_pool_args = {}
        if configuration.assert_hostname is not None:
            addition_pool_args["assert_hostname"] = (
                configuration.assert_hostname
            )  # noqa: E501

        if configuration.retries is not None:
            addition_pool_args["retries"] = configuration.retries

        if configuration.tls_server_name:
            addition_pool_args["server_hostname"] = configuration.tls_server_name

        if configuration.socket_options is not None:
            addition_pool_args["socket_options"] = configuration.socket_options

        if maxsize is None:
            if configuration.connection_pool_maxsize is not None:
                maxsize = configuration.connection_pool_maxsize
            else:
                maxsize = 4

        # https pool manager
        if configuration.proxy:
            if is_socks_proxy_url(configuration.proxy):
                from urllib3.contrib.socks import SOCKSProxyManager

                self.pool_manager = SOCKSProxyManager(
                    cert_reqs=cert_reqs,
                    ca_certs=configuration.ssl_ca_cert,
                    cert_file=configuration.cert_file,
                    key_file=configuration.key_file,
                    proxy_url=configuration.proxy,
                    headers=configuration.proxy_headers,
                    **addition_pool_args
                )
            else:
                self.pool_manager = urllib3.ProxyManager(
                    num_pools=pools_size,
                    maxsize=maxsize,
                    cert_reqs=cert_reqs,
                    ca_certs=configuration.ssl_ca_cert,
                    cert_file=configuration.cert_file,
                    key_file=configuration.key_file,
                    proxy_url=configuration.proxy,
                    proxy_headers=configuration.proxy_headers,
                    **addition_pool_args
                )
        else:
            self.pool_manager = urllib3.PoolManager(
                num_pools=pools_size,
                maxsize=maxsize,
                cert_reqs=cert_reqs,
                ca_certs=configuration.ssl_ca_cert,
                cert_file=configuration.cert_file,
                key_file=configuration.key_file,
                **addition_pool_args
            )

    def request(
        self,
        method,
        url,
        query_params=None,
        headers=None,
        body=None,
        post_params=None,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Perform requests.

        :param method: http request method
        :param url: http request url
        :param query_params: query parameters in the url
        :param headers: http request headers
        :param body: request json body, for `application/json`
        :param post_params: request post parameters,
                            `application/x-www-form-urlencoded`
                            and `multipart/form-data`
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        """
        method = method.upper()
        assert method in ["GET", "HEAD", "DELETE", "POST", "PUT", "PATCH", "OPTIONS"]

        if post_params and body:
            raise ApiValueError(
                "body parameter cannot be used with post_params parameter."
            )

        post_params = post_params or {}
        headers = headers or {}
        # url already contains the URL query string
        # so reset query_params to empty dict
        query_params = {}

        timeout = None
        if _request_timeout:
            if isinstance(_request_timeout, (int, float)):  # noqa: E501,F821
                timeout = urllib3.Timeout(total=_request_timeout)
            elif isinstance(_request_timeout, tuple) and len(_request_timeout) == 2:
                timeout = urllib3.Timeout(
                    connect=_request_timeout[0], read=_request_timeout[1]
                )

        try:
            # For `POST`, `PUT`, `PATCH`, `OPTIONS`, `DELETE`
            if method in ["POST", "PUT", "PATCH", "OPTIONS", "DELETE"]:

                # no content type provided or payload is json
                if not headers.get("Content-Type") or re.search(
                    "json", headers["Content-Type"], re.IGNORECASE
                ):
                    request_body = None
                    if body is not None:
                        request_body = json.dumps(body)
                    r = self.pool_manager.request(
                        method,
                        url,
                        body=request_body,
                        preload_content=_preload_content,
                        timeout=timeout,
                        headers=headers,
                    )
                elif (
                    headers["Content-Type"] == "application/x-www-form-urlencoded"
                ):  # noqa: E501
                    r = self.pool_manager.request(
                        method,
                        url,
                        fields=post_params,
                        encode_multipart=False,
                        preload_content=_preload_content,
                        timeout=timeout,
                        headers=headers,
                    )
                elif headers["Content-Type"] == "multipart/form-data":
                    # must del headers['Content-Type'], or the correct
                    # Content-Type which generated by urllib3 will be
                    # overwritten.
                    del headers["Content-Type"]
                    r = self.pool_manager.request(
                        method,
                        url,
                        fields=post_params,
                        encode_multipart=True,
                        preload_content=_preload_content,
                        timeout=timeout,
                        headers=headers,
                    )
                # Pass a `string` parameter directly in the body to support
                # other content types than Json when `body` argument is
                # provided in serialized form
                elif isinstance(body, str) or isinstance(body, bytes):
                    request_body = body
                    r = self.pool_manager.request(
                        method,
                        url,
                        body=request_body,
                        preload_content=_preload_content,
                        timeout=timeout,
                        headers=headers,
                    )
                else:
                    # Cannot generate the request from given parameters
                    msg = """Cannot prepare a request message for provided
                             arguments. Please check that your arguments match
                             declared content type."""
                    raise ApiException(status=0, reason=msg)
            # For `GET`, `HEAD`
            else:
                r = self.pool_manager.request(
                    method,
                    url,
                    fields={},
                    preload_content=_preload_content,
                    timeout=timeout,
                    headers=headers,
                )
        except urllib3.exceptions.SSLError as e:
            msg = "{0}\n{1}".format(type(e).__name__, str(e))
            raise ApiException(status=0, reason=msg)

        if _preload_content:
            r = RESTResponse(r)

            # log response body
            logger.debug("response body: %s", r.data)

        if not 200 <= r.status <= 299:
            if r.status == 400:
                raise BadRequestException(http_resp=r)

            if r.status == 401:
                raise UnauthorizedException(http_resp=r)

            if r.status == 403:
                raise ForbiddenException(http_resp=r)

            if r.status == 404:
                raise NotFoundException(http_resp=r)

            if 500 <= r.status <= 599:
                raise ServiceException(http_resp=r)

            raise ApiException(http_resp=r)

        return r

    def get_request(
        self,
        url,
        headers=None,
        query_params=None,
        _preload_content=True,
        _request_timeout=None,
    ):
        return self.request(
            "GET",
            url,
            headers=headers,
            _preload_content=_preload_content,
            _request_timeout=_request_timeout,
            query_params=query_params,
        )

    def head_request(
        self,
        url,
        headers=None,
        query_params=None,
        _preload_content=True,
        _request_timeout=None,
    ):
        return self.request(
            "HEAD",
            url,
            headers=headers,
            _preload_content=_preload_content,
            _request_timeout=_request_timeout,
            query_params=query_params,
        )

    def options_request(
        self,
        url,
        headers=None,
        query_params=None,
        post_params=None,
        body=None,
        _preload_content=True,
        _request_timeout=None,
    ):
        return self.request(
            "OPTIONS",
            url,
            headers=headers,
            query_params=query_params,
            post_params=post_params,
            _preload_content=_preload_content,
            _request_timeout=_request_timeout,
            body=body,
        )

    def delete_request(
        self,
        url,
        headers=None,
        query_params=None,
        body=None,
        _preload_content=True,
        _request_timeout=None,
    ):
        return self.request(
            "DELETE",
            url,
            headers=headers,
            query_params=query_params,
            _preload_content=_preload_content,
            _request_timeout=_request_timeout,
            body=body,
        )

    def post_request(
        self,
        url,
        headers=None,
        query_params=None,
        post_params=None,
        body=None,
        _preload_content=True,
        _request_timeout=None,
    ):
        return self.request(
            "POST",
            url,
            headers=headers,
            query_params=query_params,
            post_params=post_params,
            _preload_content=_preload_content,
            _request_timeout=_request_timeout,
            body=body,
        )

    def put_request(
        self,
        url,
        headers=None,
        query_params=None,
        post_params=None,
        body=None,
        _preload_content=True,
        _request_timeout=None,
    ):
        return self.request(
            "PUT",
            url,
            headers=headers,
            query_params=query_params,
            post_params=post_params,
            _preload_content=_preload_content,
            _request_timeout=_request_timeout,
            body=body,
        )

    def patch_request(
        self,
        url,
        headers=None,
        query_params=None,
        post_params=None,
        body=None,
        _preload_content=True,
        _request_timeout=None,
    ):
        return self.request(
            "PATCH",
            url,
            headers=headers,
            query_params=query_params,
            post_params=post_params,
            _preload_content=_preload_content,
            _request_timeout=_request_timeout,
            body=body,
        )



# coding: utf-8

# flake8: noqa

"""
    Amber Electric Public API

    Amber is an Australian-based electricity retailer that pass through the real-time wholesale price of energy.  Because of Amber's wholesale power prices, you can save hundreds of dollars a year by automating high power devices like air-conditioners, heat pumps and pool pumps.  This Python library provides an interface to the API, allowing you to react to current and forecast prices, as well as download your historic usage.

    The version of the OpenAPI document: 2.0.0
    Contact: dev@amber.com.au
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "2.0.3"

# import apis into sdk package
from amberelectric.api.amber_api import AmberApi

# import ApiClient
from amberelectric.api_response import ApiResponse
from amberelectric.api_client import ApiClient
from amberelectric.configuration import Configuration
from amberelectric.exceptions import OpenApiException
from amberelectric.exceptions import ApiTypeError
from amberelectric.exceptions import ApiValueError
from amberelectric.exceptions import ApiKeyError
from amberelectric.exceptions import ApiAttributeError
from amberelectric.exceptions import ApiException

# import models into sdk package
from amberelectric.models.actual_interval import ActualInterval
from amberelectric.models.actual_renewable import ActualRenewable
from amberelectric.models.advanced_price import AdvancedPrice
from amberelectric.models.base_interval import BaseInterval
from amberelectric.models.base_renewable import BaseRenewable
from amberelectric.models.channel import Channel
from amberelectric.models.channel_type import ChannelType
from amberelectric.models.current_interval import CurrentInterval
from amberelectric.models.current_renewable import CurrentRenewable
from amberelectric.models.forecast_interval import ForecastInterval
from amberelectric.models.forecast_renewable import ForecastRenewable
from amberelectric.models.interval import Interval
from amberelectric.models.price_descriptor import PriceDescriptor
from amberelectric.models.range import Range
from amberelectric.models.renewable import Renewable
from amberelectric.models.renewable_descriptor import RenewableDescriptor
from amberelectric.models.site import Site
from amberelectric.models.site_status import SiteStatus
from amberelectric.models.spike_status import SpikeStatus
from amberelectric.models.tariff_information import TariffInformation
from amberelectric.models.usage import Usage



# coding: utf-8

"""
    Amber Electric Public API

    Amber is an Australian-based electricity retailer that pass through the real-time wholesale price of energy.  Because of Amber's wholesale power prices, you can save hundreds of dollars a year by automating high power devices like air-conditioners, heat pumps and pool pumps.  This Python library provides an interface to the API, allowing you to react to current and forecast prices, as well as download your historic usage.

    The version of the OpenAPI document: 2.0.0
    Contact: dev@amber.com.au
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import re  # noqa: F401
import io
import warnings

try:
    from pydantic.v1 import validate_arguments
except ImportError:
    from pydantic import validate_arguments

from typing_extensions import Annotated
from datetime import date

from pydantic import Field, StrictInt, StrictStr

from typing import List, Optional

from amberelectric.models.interval import Interval
from amberelectric.models.renewable import Renewable
from amberelectric.models.site import Site
from amberelectric.models.usage import Usage

from amberelectric.api_client import ApiClient
from amberelectric.api_response import ApiResponse
from amberelectric.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class AmberApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def get_current_prices(
        self,
        site_id: Annotated[
            StrictStr,
            Field(
                ...,
                description="ID of the site you are fetching prices for. Can be found using the `/sites` enpoint",
            ),
        ],
        next: Annotated[
            Optional[StrictInt],
            Field(description="Return the _next_ number of forecast intervals"),
        ] = None,
        previous: Annotated[
            Optional[StrictInt],
            Field(description="Return the _previous_ number of actual intervals."),
        ] = None,
        resolution: Annotated[
            Optional[StrictInt],
            Field(
                description="Specify the required interval duration resolution. Valid options: 30. Default: 30"
            ),
        ] = None,
        **kwargs
    ) -> List[Interval]:  # noqa: E501
        """get_current_prices  # noqa: E501

        Returns the current price  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_current_prices(site_id, next, previous, resolution, async_req=True)
        >>> result = thread.get()

        :param site_id: ID of the site you are fetching prices for. Can be found using the `/sites` enpoint (required)
        :type site_id: str
        :param next: Return the _next_ number of forecast intervals
        :type next: int
        :param previous: Return the _previous_ number of actual intervals.
        :type previous: int
        :param resolution: Specify the required interval duration resolution. Valid options: 30. Default: 30
        :type resolution: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: List[Interval]
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the get_current_prices_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_current_prices_with_http_info(
            site_id, next, previous, resolution, **kwargs
        )  # noqa: E501

    @validate_arguments
    def get_current_prices_with_http_info(
        self,
        site_id: Annotated[
            StrictStr,
            Field(
                ...,
                description="ID of the site you are fetching prices for. Can be found using the `/sites` enpoint",
            ),
        ],
        next: Annotated[
            Optional[StrictInt],
            Field(description="Return the _next_ number of forecast intervals"),
        ] = None,
        previous: Annotated[
            Optional[StrictInt],
            Field(description="Return the _previous_ number of actual intervals."),
        ] = None,
        resolution: Annotated[
            Optional[StrictInt],
            Field(
                description="Specify the required interval duration resolution. Valid options: 30. Default: 30"
            ),
        ] = None,
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """get_current_prices  # noqa: E501

        Returns the current price  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_current_prices_with_http_info(site_id, next, previous, resolution, async_req=True)
        >>> result = thread.get()

        :param site_id: ID of the site you are fetching prices for. Can be found using the `/sites` enpoint (required)
        :type site_id: str
        :param next: Return the _next_ number of forecast intervals
        :type next: int
        :param previous: Return the _previous_ number of actual intervals.
        :type previous: int
        :param resolution: Specify the required interval duration resolution. Valid options: 30. Default: 30
        :type resolution: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(List[Interval], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["site_id", "next", "previous", "resolution"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_current_prices" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["site_id"] is not None:
            _path_params["siteId"] = _params["site_id"]

        # process the query parameters
        _query_params = []
        if _params.get("next") is not None:  # noqa: E501
            _query_params.append(("next", _params["next"]))

        if _params.get("previous") is not None:  # noqa: E501
            _query_params.append(("previous", _params["previous"]))

        if _params.get("resolution") is not None:  # noqa: E501
            _query_params.append(("resolution", _params["resolution"]))

        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # authentication setting
        _auth_settings = ["apiKey"]  # noqa: E501

        _response_types_map = {
            "200": "List[Interval]",
            "400": None,
            "401": None,
            "404": None,
            "500": None,
        }

        return self.api_client.call_api(
            "/sites/{siteId}/prices/current",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def get_current_renewables(
        self,
        state: Annotated[
            StrictStr,
            Field(
                ...,
                description="State you would like the renewables for. Valid states: nsw, sa, qld, vic",
            ),
        ],
        next: Annotated[
            Optional[StrictInt],
            Field(description="Return the _next_ number of forecast intervals"),
        ] = None,
        previous: Annotated[
            Optional[StrictInt],
            Field(description="Return the _previous_ number of actual intervals."),
        ] = None,
        resolution: Annotated[
            Optional[StrictInt],
            Field(
                description="Specify the required interval duration resolution. Valid options: 5, 30. Default: 30"
            ),
        ] = None,
        **kwargs
    ) -> List[Renewable]:  # noqa: E501
        """get_current_renewables  # noqa: E501

        Returns the current percentage of renewables in the grid  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_current_renewables(state, next, previous, resolution, async_req=True)
        >>> result = thread.get()

        :param state: State you would like the renewables for. Valid states: nsw, sa, qld, vic (required)
        :type state: str
        :param next: Return the _next_ number of forecast intervals
        :type next: int
        :param previous: Return the _previous_ number of actual intervals.
        :type previous: int
        :param resolution: Specify the required interval duration resolution. Valid options: 5, 30. Default: 30
        :type resolution: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: List[Renewable]
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the get_current_renewables_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_current_renewables_with_http_info(
            state, next, previous, resolution, **kwargs
        )  # noqa: E501

    @validate_arguments
    def get_current_renewables_with_http_info(
        self,
        state: Annotated[
            StrictStr,
            Field(
                ...,
                description="State you would like the renewables for. Valid states: nsw, sa, qld, vic",
            ),
        ],
        next: Annotated[
            Optional[StrictInt],
            Field(description="Return the _next_ number of forecast intervals"),
        ] = None,
        previous: Annotated[
            Optional[StrictInt],
            Field(description="Return the _previous_ number of actual intervals."),
        ] = None,
        resolution: Annotated[
            Optional[StrictInt],
            Field(
                description="Specify the required interval duration resolution. Valid options: 5, 30. Default: 30"
            ),
        ] = None,
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """get_current_renewables  # noqa: E501

        Returns the current percentage of renewables in the grid  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_current_renewables_with_http_info(state, next, previous, resolution, async_req=True)
        >>> result = thread.get()

        :param state: State you would like the renewables for. Valid states: nsw, sa, qld, vic (required)
        :type state: str
        :param next: Return the _next_ number of forecast intervals
        :type next: int
        :param previous: Return the _previous_ number of actual intervals.
        :type previous: int
        :param resolution: Specify the required interval duration resolution. Valid options: 5, 30. Default: 30
        :type resolution: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(List[Renewable], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["state", "next", "previous", "resolution"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_current_renewables" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["state"] is not None:
            _path_params["state"] = _params["state"]

        # process the query parameters
        _query_params = []
        if _params.get("next") is not None:  # noqa: E501
            _query_params.append(("next", _params["next"]))

        if _params.get("previous") is not None:  # noqa: E501
            _query_params.append(("previous", _params["previous"]))

        if _params.get("resolution") is not None:  # noqa: E501
            _query_params.append(("resolution", _params["resolution"]))

        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            "200": "List[Renewable]",
            "400": None,
            "404": None,
            "500": None,
        }

        return self.api_client.call_api(
            "/state/{state}/renewables/current",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def get_prices(
        self,
        site_id: Annotated[
            StrictStr,
            Field(
                ...,
                description="ID of the site you are fetching prices for. Can be found using the `/sites` endpoint",
            ),
        ],
        start_date: Annotated[
            Optional[date],
            Field(
                description="Return all prices for each interval on and after this day. Defaults to today."
            ),
        ] = None,
        end_date: Annotated[
            Optional[date],
            Field(
                description="Return all prices for each interval on and before this day. Defaults to today."
            ),
        ] = None,
        resolution: Annotated[
            Optional[StrictInt],
            Field(
                description="Specify the required interval duration resolution. Valid options: 5, 30. Default: 30"
            ),
        ] = None,
        **kwargs
    ) -> List[Interval]:  # noqa: E501
        """get_prices  # noqa: E501

        Returns all the prices between the start and end dates  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_prices(site_id, start_date, end_date, resolution, async_req=True)
        >>> result = thread.get()

        :param site_id: ID of the site you are fetching prices for. Can be found using the `/sites` endpoint (required)
        :type site_id: str
        :param start_date: Return all prices for each interval on and after this day. Defaults to today.
        :type start_date: date
        :param end_date: Return all prices for each interval on and before this day. Defaults to today.
        :type end_date: date
        :param resolution: Specify the required interval duration resolution. Valid options: 5, 30. Default: 30
        :type resolution: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: List[Interval]
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the get_prices_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_prices_with_http_info(
            site_id, start_date, end_date, resolution, **kwargs
        )  # noqa: E501

    @validate_arguments
    def get_prices_with_http_info(
        self,
        site_id: Annotated[
            StrictStr,
            Field(
                ...,
                description="ID of the site you are fetching prices for. Can be found using the `/sites` endpoint",
            ),
        ],
        start_date: Annotated[
            Optional[date],
            Field(
                description="Return all prices for each interval on and after this day. Defaults to today."
            ),
        ] = None,
        end_date: Annotated[
            Optional[date],
            Field(
                description="Return all prices for each interval on and before this day. Defaults to today."
            ),
        ] = None,
        resolution: Annotated[
            Optional[StrictInt],
            Field(
                description="Specify the required interval duration resolution. Valid options: 5, 30. Default: 30"
            ),
        ] = None,
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """get_prices  # noqa: E501

        Returns all the prices between the start and end dates  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_prices_with_http_info(site_id, start_date, end_date, resolution, async_req=True)
        >>> result = thread.get()

        :param site_id: ID of the site you are fetching prices for. Can be found using the `/sites` endpoint (required)
        :type site_id: str
        :param start_date: Return all prices for each interval on and after this day. Defaults to today.
        :type start_date: date
        :param end_date: Return all prices for each interval on and before this day. Defaults to today.
        :type end_date: date
        :param resolution: Specify the required interval duration resolution. Valid options: 5, 30. Default: 30
        :type resolution: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(List[Interval], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["site_id", "start_date", "end_date", "resolution"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_prices" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["site_id"] is not None:
            _path_params["siteId"] = _params["site_id"]

        # process the query parameters
        _query_params = []
        if _params.get("start_date") is not None:  # noqa: E501
            if isinstance(_params["start_date"], date):
                _query_params.append(
                    (
                        "startDate",
                        _params["start_date"].strftime(
                            self.api_client.configuration.date_format
                        ),
                    )
                )
            else:
                _query_params.append(("startDate", _params["start_date"]))

        if _params.get("end_date") is not None:  # noqa: E501
            if isinstance(_params["end_date"], date):
                _query_params.append(
                    (
                        "endDate",
                        _params["end_date"].strftime(
                            self.api_client.configuration.date_format
                        ),
                    )
                )
            else:
                _query_params.append(("endDate", _params["end_date"]))

        if _params.get("resolution") is not None:  # noqa: E501
            _query_params.append(("resolution", _params["resolution"]))

        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # authentication setting
        _auth_settings = ["apiKey"]  # noqa: E501

        _response_types_map = {
            "200": "List[Interval]",
            "400": None,
            "401": None,
            "404": None,
            "500": None,
        }

        return self.api_client.call_api(
            "/sites/{siteId}/prices",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def get_sites(self, **kwargs) -> List[Site]:  # noqa: E501
        """get_sites  # noqa: E501

        Return all sites linked to your account  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_sites(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: List[Site]
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the get_sites_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_sites_with_http_info(**kwargs)  # noqa: E501

    @validate_arguments
    def get_sites_with_http_info(self, **kwargs) -> ApiResponse:  # noqa: E501
        """get_sites  # noqa: E501

        Return all sites linked to your account  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_sites_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(List[Site], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = []
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sites" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # authentication setting
        _auth_settings = ["apiKey"]  # noqa: E501

        _response_types_map = {
            "200": "List[Site]",
            "401": None,
            "500": None,
        }

        return self.api_client.call_api(
            "/sites",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def get_usage(
        self,
        site_id: Annotated[
            StrictStr,
            Field(
                ...,
                description="ID of the site you are fetching usage for. Can be found using the `/sites` enpoint",
            ),
        ],
        start_date: Annotated[
            date,
            Field(
                ...,
                description="Return all usage for each interval on and after this day.",
            ),
        ],
        end_date: Annotated[
            date,
            Field(
                ...,
                description="Return all usage for each interval on and before this day.",
            ),
        ],
        resolution: Annotated[
            Optional[StrictInt],
            Field(
                description="Specify the required interval duration resolution. Valid options: 30. Default: 30"
            ),
        ] = None,
        **kwargs
    ) -> List[Usage]:  # noqa: E501
        """get_usage  # noqa: E501

        Returns all usage data between the start and end dates. The API can only return 90-days worth of data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_usage(site_id, start_date, end_date, resolution, async_req=True)
        >>> result = thread.get()

        :param site_id: ID of the site you are fetching usage for. Can be found using the `/sites` enpoint (required)
        :type site_id: str
        :param start_date: Return all usage for each interval on and after this day. (required)
        :type start_date: date
        :param end_date: Return all usage for each interval on and before this day. (required)
        :type end_date: date
        :param resolution: Specify the required interval duration resolution. Valid options: 30. Default: 30
        :type resolution: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: List[Usage]
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the get_usage_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_usage_with_http_info(
            site_id, start_date, end_date, resolution, **kwargs
        )  # noqa: E501

    @validate_arguments
    def get_usage_with_http_info(
        self,
        site_id: Annotated[
            StrictStr,
            Field(
                ...,
                description="ID of the site you are fetching usage for. Can be found using the `/sites` enpoint",
            ),
        ],
        start_date: Annotated[
            date,
            Field(
                ...,
                description="Return all usage for each interval on and after this day.",
            ),
        ],
        end_date: Annotated[
            date,
            Field(
                ...,
                description="Return all usage for each interval on and before this day.",
            ),
        ],
        resolution: Annotated[
            Optional[StrictInt],
            Field(
                description="Specify the required interval duration resolution. Valid options: 30. Default: 30"
            ),
        ] = None,
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """get_usage  # noqa: E501

        Returns all usage data between the start and end dates. The API can only return 90-days worth of data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_usage_with_http_info(site_id, start_date, end_date, resolution, async_req=True)
        >>> result = thread.get()

        :param site_id: ID of the site you are fetching usage for. Can be found using the `/sites` enpoint (required)
        :type site_id: str
        :param start_date: Return all usage for each interval on and after this day. (required)
        :type start_date: date
        :param end_date: Return all usage for each interval on and before this day. (required)
        :type end_date: date
        :param resolution: Specify the required interval duration resolution. Valid options: 30. Default: 30
        :type resolution: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(List[Usage], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["site_id", "start_date", "end_date", "resolution"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_usage" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["site_id"] is not None:
            _path_params["siteId"] = _params["site_id"]

        # process the query parameters
        _query_params = []
        if _params.get("start_date") is not None:  # noqa: E501
            if isinstance(_params["start_date"], date):
                _query_params.append(
                    (
                        "startDate",
                        _params["start_date"].strftime(
                            self.api_client.configuration.date_format
                        ),
                    )
                )
            else:
                _query_params.append(("startDate", _params["start_date"]))

        if _params.get("end_date") is not None:  # noqa: E501
            if isinstance(_params["end_date"], date):
                _query_params.append(
                    (
                        "endDate",
                        _params["end_date"].strftime(
                            self.api_client.configuration.date_format
                        ),
                    )
                )
            else:
                _query_params.append(("endDate", _params["end_date"]))

        if _params.get("resolution") is not None:  # noqa: E501
            _query_params.append(("resolution", _params["resolution"]))

        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # authentication setting
        _auth_settings = ["apiKey"]  # noqa: E501

        _response_types_map = {
            "200": "List[Usage]",
            "400": None,
            "401": None,
            "404": None,
            "500": None,
        }

        return self.api_client.call_api(
            "/sites/{siteId}/usage",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )



# coding: utf-8

"""
    Amber Electric Public API

    Amber is an Australian-based electricity retailer that pass through the real-time wholesale price of energy.  Because of Amber's wholesale power prices, you can save hundreds of dollars a year by automating high power devices like air-conditioners, heat pumps and pool pumps.  This Python library provides an interface to the API, allowing you to react to current and forecast prices, as well as download your historic usage.

    The version of the OpenAPI document: 2.0.0
    Contact: dev@amber.com.au
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


try:

    from pydantic.v1 import BaseModel, Field, StrictStr
except ImportError:

    from pydantic import BaseModel, Field, StrictStr
from amberelectric.models.channel_type import ChannelType


class Channel(BaseModel):
    """
    Describes a power meter channel.  The General channel provides continuous power - it's the channel all of your appliances and lights are attached to.  Controlled loads are only on for a limited time during the day (usually when the load on the network is low, or generation is high) - you may have your hot water system attached to this channel.  The feed in channel sends power back to the grid - you will have these types of channels if you have solar or batteries.  # noqa: E501
    """

    identifier: StrictStr = Field(default=..., description="Identifier of the channel")
    type: ChannelType = Field(...)
    tariff: StrictStr = Field(default=..., description="The tariff code of the channel")
    __properties = ["identifier", "type", "tariff"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Channel:
        """Create an instance of Channel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Channel:
        """Create an instance of Channel from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Channel.parse_obj(obj)

        _obj = Channel.parse_obj(
            {
                "identifier": obj.get("identifier"),
                "type": obj.get("type"),
                "tariff": obj.get("tariff"),
            }
        )
        return _obj



# coding: utf-8

"""
    Amber Electric Public API

    Amber is an Australian-based electricity retailer that pass through the real-time wholesale price of energy.  Because of Amber's wholesale power prices, you can save hundreds of dollars a year by automating high power devices like air-conditioners, heat pumps and pool pumps.  This Python library provides an interface to the API, allowing you to react to current and forecast prices, as well as download your historic usage.

    The version of the OpenAPI document: 2.0.0
    Contact: dev@amber.com.au
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from amberelectric.models.renewable_descriptor import RenewableDescriptor  # noqa: E501

class TestRenewableDescriptor(unittest.TestCase):
    """RenewableDescriptor unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRenewableDescriptor(self):
        """Test RenewableDescriptor"""
        # inst = RenewableDescriptor()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Amber Electric Public API

    Amber is an Australian-based electricity retailer that pass through the real-time wholesale price of energy.  Because of Amber's wholesale power prices, you can save hundreds of dollars a year by automating high power devices like air-conditioners, heat pumps and pool pumps.  This Python library provides an interface to the API, allowing you to react to current and forecast prices, as well as download your historic usage.

    The version of the OpenAPI document: 2.0.0
    Contact: dev@amber.com.au
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
from aenum import Enum  # type: ignore
from typing import Type, TypeVar

T = TypeVar("T", bound="PriceDescriptor")


try:
    pass

except ImportError:
    pass


class PriceDescriptor(str, Enum):
    """
    Describes the current price. Gives you an indication of how cheap the price is in relation to the average VMO and DMO. Note: Negative is no longer used. It has been replaced with extremelyLow.
    """

    """
    allowed enum values
    """
    NEGATIVE = "negative"
    EXTREMELYLOW = "extremelyLow"
    VERYLOW = "veryLow"
    LOW = "low"
    NEUTRAL = "neutral"
    HIGH = "high"
    SPIKE = "spike"

    @classmethod
    def from_json(cls: Type[T], json_str: str) -> T:
        """Create an instance of PriceDescriptor from a JSON string"""
        return PriceDescriptor(json.loads(json_str))



# coding: utf-8

"""
    Amber Electric Public API

    Amber is an Australian-based electricity retailer that pass through the real-time wholesale price of energy.  Because of Amber's wholesale power prices, you can save hundreds of dollars a year by automating high power devices like air-conditioners, heat pumps and pool pumps.  This Python library provides an interface to the API, allowing you to react to current and forecast prices, as well as download your historic usage.

    The version of the OpenAPI document: 2.0.0
    Contact: dev@amber.com.au
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date, datetime

try:

    from pydantic.v1 import BaseModel, Field, StrictInt, StrictStr, confloat, validator
except ImportError:

    from pydantic import BaseModel, Field, StrictInt, StrictStr, confloat, validator
from amberelectric.models.renewable_descriptor import RenewableDescriptor


class BaseRenewable(BaseModel):
    """
    Renewable data  # noqa: E501
    """

    type: StrictStr = Field(...)
    duration: StrictInt = Field(
        default=..., description="Length of the interval in minutes."
    )
    var_date: date = Field(
        default=...,
        alias="date",
        description="Date the interval belongs to (in NEM time). This may be different to the date component of nemTime, as the last interval of the day ends at 12:00 the following day. Formatted as a ISO 8601 date",
    )
    nem_time: datetime = Field(
        default=...,
        alias="nemTime",
        description="The interval's NEM time. This represents the time at the end of the interval UTC+10. Formatted as a ISO 8601 time",
    )
    start_time: datetime = Field(
        default=...,
        alias="startTime",
        description="Start time of the interval in UTC. Formatted as a ISO 8601 time",
    )
    end_time: datetime = Field(
        default=...,
        alias="endTime",
        description="End time of the interval in UTC. Formatted as a ISO 8601 time",
    )
    renewables: confloat(le=100, ge=0) = Field(
        default=..., description="Percentage of renewables in the grid"
    )
    descriptor: RenewableDescriptor = Field(...)
    __properties = [
        "type",
        "duration",
        "date",
        "nemTime",
        "startTime",
        "endTime",
        "renewables",
        "descriptor",
    ]

    @validator("duration")
    def duration_validate_enum(cls, value):
        """Validates the enum"""
        if value not in (5, 15, 30):
            raise ValueError("must be one of enum values (5, 15, 30)")
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> BaseRenewable:
        """Create an instance of BaseRenewable from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> BaseRenewable:
        """Create an instance of BaseRenewable from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return BaseRenewable.parse_obj(obj)

        _obj = BaseRenewable.parse_obj(
            {
                "type": obj.get("type"),
                "duration": obj.get("duration"),
                "var_date": obj.get("date"),
                "nem_time": obj.get("nemTime"),
                "start_time": obj.get("startTime"),
                "end_time": obj.get("endTime"),
                "renewables": obj.get("renewables"),
                "descriptor": obj.get("descriptor"),
            }
        )
        return _obj



# coding: utf-8

"""
    Amber Electric Public API

    Amber is an Australian-based electricity retailer that pass through the real-time wholesale price of energy.  Because of Amber's wholesale power prices, you can save hundreds of dollars a year by automating high power devices like air-conditioners, heat pumps and pool pumps.  This Python library provides an interface to the API, allowing you to react to current and forecast prices, as well as download your historic usage.

    The version of the OpenAPI document: 2.0.0
    Contact: dev@amber.com.au
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional

try:

    from pydantic.v1 import BaseModel, Field, StrictBool, StrictStr, confloat, validator
except ImportError:

    from pydantic import BaseModel, Field, StrictBool, StrictStr, confloat, validator


class TariffInformation(BaseModel):
    """
    Information about how your tariff affects an interval  # noqa: E501
    """

    period: Optional[StrictStr] = Field(
        default=None,
        description="The Time of Use period that is currently active. Only available if the site in on a time of use tariff",
    )
    season: Optional[StrictStr] = Field(
        default=None,
        description="The Time of Use season that is currently active. Only available if the site in on a time of use tariff",
    )
    block: Optional[confloat(le=2, ge=1)] = Field(
        default=None,
        description="The block that is currently active. Only available in the site in on a block tariff",
    )
    demand_window: Optional[StrictBool] = Field(
        default=None,
        alias="demandWindow",
        description="Is this interval currently in the demand window? Only available if the site in on a demand tariff",
    )
    __properties = ["period", "season", "block", "demandWindow"]

    @validator("period")
    def period_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ("offPeak", "shoulder", "solarSponge", "peak"):
            raise ValueError(
                "must be one of enum values ('offPeak', 'shoulder', 'solarSponge', 'peak')"
            )
        return value

    @validator("season")
    def season_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in (
            "default",
            "summer",
            "autumn",
            "winter",
            "spring",
            "nonSummer",
            "holiday",
            "weekend",
            "weekendHoliday",
            "weekday",
        ):
            raise ValueError(
                "must be one of enum values ('default', 'summer', 'autumn', 'winter', 'spring', 'nonSummer', 'holiday', 'weekend', 'weekendHoliday', 'weekday')"
            )
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TariffInformation:
        """Create an instance of TariffInformation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TariffInformation:
        """Create an instance of TariffInformation from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TariffInformation.parse_obj(obj)

        _obj = TariffInformation.parse_obj(
            {
                "period": obj.get("period"),
                "season": obj.get("season"),
                "block": obj.get("block"),
                "demand_window": obj.get("demandWindow"),
            }
        )
        return _obj



# coding: utf-8

"""
    Amber Electric Public API

    Amber is an Australian-based electricity retailer that pass through the real-time wholesale price of energy.  Because of Amber's wholesale power prices, you can save hundreds of dollars a year by automating high power devices like air-conditioners, heat pumps and pool pumps.  This Python library provides an interface to the API, allowing you to react to current and forecast prices, as well as download your historic usage.

    The version of the OpenAPI document: 2.0.0
    Contact: dev@amber.com.au
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
from aenum import Enum  # type: ignore
from typing import Type, TypeVar

T = TypeVar("T", bound="SiteStatus")


try:
    pass

except ImportError:
    pass


class SiteStatus(str, Enum):
    """
    Site status.  Pending sites are still in the process of being transferred. Note: We only include sites that have correct address details. If you expect to see a site, but don't, you may need to contact [info@amber.com.au](mailto:info@amber.com.au) to check that the address is correct.  Active sites are ones that we actively supply electricity to.  Closed sites are old sites that we no longer supply.
    """

    """
    allowed enum values
    """
    PENDING = "pending"
    ACTIVE = "active"
    CLOSED = "closed"

    @classmethod
    def from_json(cls: Type[T], json_str: str) -> T:
        """Create an instance of SiteStatus from a JSON string"""
        return SiteStatus(json.loads(json_str))



# coding: utf-8

"""
    Amber Electric Public API

    Amber is an Australian-based electricity retailer that pass through the real-time wholesale price of energy.  Because of Amber's wholesale power prices, you can save hundreds of dollars a year by automating high power devices like air-conditioners, heat pumps and pool pumps.  This Python library provides an interface to the API, allowing you to react to current and forecast prices, as well as download your historic usage.

    The version of the OpenAPI document: 2.0.0
    Contact: dev@amber.com.au
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
import pprint
import re  # noqa: F401

from typing import Any, List, Optional

try:

    from pydantic.v1 import BaseModel, Field, StrictStr, ValidationError, validator
except ImportError:

    from pydantic import BaseModel, Field, StrictStr, ValidationError, validator
from amberelectric.models.actual_renewable import ActualRenewable
from amberelectric.models.current_renewable import CurrentRenewable
from amberelectric.models.forecast_renewable import ForecastRenewable
from typing import Union, Any, List, TYPE_CHECKING

RENEWABLE_ONE_OF_SCHEMAS = ["ActualRenewable", "CurrentRenewable", "ForecastRenewable"]


class Renewable(BaseModel):
    """
    Renewable
    """

    # data type: ActualRenewable
    oneof_schema_1_validator: Optional[ActualRenewable] = None
    # data type: CurrentRenewable
    oneof_schema_2_validator: Optional[CurrentRenewable] = None
    # data type: ForecastRenewable
    oneof_schema_3_validator: Optional[ForecastRenewable] = None
    if TYPE_CHECKING:
        actual_instance: Union[ActualRenewable, CurrentRenewable, ForecastRenewable]
    else:
        actual_instance: Any
    one_of_schemas: List[str] = Field(RENEWABLE_ONE_OF_SCHEMAS, const=True)

    class Config:
        validate_assignment = True

    def __init__(self, *args, **kwargs) -> None:
        if args:
            if len(args) > 1:
                raise ValueError(
                    "If a position argument is used, only 1 is allowed to set `actual_instance`"
                )
            if kwargs:
                raise ValueError(
                    "If a position argument is used, keyword arguments cannot be used."
                )
            super().__init__(actual_instance=args[0])
        else:
            super().__init__(**kwargs)

    @validator("actual_instance")
    def actual_instance_must_validate_oneof(cls, v):
        instance = Renewable.construct()
        error_messages = []
        match = 0
        # validate data type: ActualRenewable
        if not isinstance(v, ActualRenewable):
            error_messages.append(
                f"Error! Input type `{type(v)}` is not `ActualRenewable`"
            )
        else:
            match += 1
        # validate data type: CurrentRenewable
        if not isinstance(v, CurrentRenewable):
            error_messages.append(
                f"Error! Input type `{type(v)}` is not `CurrentRenewable`"
            )
        else:
            match += 1
        # validate data type: ForecastRenewable
        if not isinstance(v, ForecastRenewable):
            error_messages.append(
                f"Error! Input type `{type(v)}` is not `ForecastRenewable`"
            )
        else:
            match += 1
        if match > 1:
            # more than 1 match
            raise ValueError(
                "Multiple matches found when setting `actual_instance` in Renewable with oneOf schemas: ActualRenewable, CurrentRenewable, ForecastRenewable. Details: "
                + ", ".join(error_messages)
            )
        elif match == 0:
            # no match
            raise ValueError(
                "No match found when setting `actual_instance` in Renewable with oneOf schemas: ActualRenewable, CurrentRenewable, ForecastRenewable. Details: "
                + ", ".join(error_messages)
            )
        else:
            return v

    @classmethod
    def from_dict(cls, obj: dict) -> Renewable:
        return cls.from_json(json.dumps(obj))

    @classmethod
    def from_json(cls, json_str: str) -> Renewable:
        """Returns the object represented by the json string"""
        instance = Renewable.construct()
        error_messages = []
        match = 0

        # deserialize data into ActualRenewable
        try:
            instance.actual_instance = ActualRenewable.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into CurrentRenewable
        try:
            instance.actual_instance = CurrentRenewable.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into ForecastRenewable
        try:
            instance.actual_instance = ForecastRenewable.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))

        if match > 1:
            # more than 1 match
            raise ValueError(
                "Multiple matches found when deserializing the JSON string into Renewable with oneOf schemas: ActualRenewable, CurrentRenewable, ForecastRenewable. Details: "
                + ", ".join(error_messages)
            )
        elif match == 0:
            # no match
            raise ValueError(
                "No match found when deserializing the JSON string into Renewable with oneOf schemas: ActualRenewable, CurrentRenewable, ForecastRenewable. Details: "
                + ", ".join(error_messages)
            )
        else:
            return instance

    def to_json(self) -> str:
        """Returns the JSON representation of the actual instance"""
        if self.actual_instance is None:
            return "null"

        to_json = getattr(self.actual_instance, "to_json", None)
        if callable(to_json):
            return self.actual_instance.to_json()
        else:
            return json.dumps(self.actual_instance)

    def to_dict(self) -> dict:
        """Returns the dict representation of the actual instance"""
        if self.actual_instance is None:
            return None

        to_dict = getattr(self.actual_instance, "to_dict", None)
        if callable(to_dict):
            return self.actual_instance.to_dict()
        else:
            # primitive type
            return self.actual_instance

    def to_str(self) -> str:
        """Returns the string representation of the actual instance"""
        return pprint.pformat(self.dict())



# coding: utf-8

"""
    Amber Electric Public API

    Amber is an Australian-based electricity retailer that pass through the real-time wholesale price of energy.  Because of Amber's wholesale power prices, you can save hundreds of dollars a year by automating high power devices like air-conditioners, heat pumps and pool pumps.  This Python library provides an interface to the API, allowing you to react to current and forecast prices, as well as download your historic usage.

    The version of the OpenAPI document: 2.0.0
    Contact: dev@amber.com.au
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "amberelectric"
VERSION = "2.0.3"
PYTHON_REQUIRES = ">=3.7"
REQUIRES = [
    "urllib3 >= 1.25.3",
    "python-dateutil >=2.8.2",
    "pydantic >= 1.10.5",
    "aenum >=3.1.11"
]

setup(
    name=NAME,
    version=VERSION,
    description="Amber Electric Public API",
    author="Amber Electric Development Team",
    author_email="dev@amber.com.au",
    url="https://github.com/madpilot/amberelectric.py",
    keywords=["OpenAPI", "OpenAPI-Generator", "Amber Electric Public API"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="Apache Software License",
    long_description_content_type='text/markdown',
    long_description="""\
    Amber is an Australian-based electricity retailer that pass through the real-time wholesale price of energy.  Because of Amber&#39;s wholesale power prices, you can save hundreds of dollars a year by automating high power devices like air-conditioners, heat pumps and pool pumps.  This Python library provides an interface to the API, allowing you to react to current and forecast prices, as well as download your historic usage.
    """,  # noqa: E501
    package_data={"amberelectric": ["py.typed"]},
)



# coding: utf-8

"""
    Amber Electric Public API

    Amber is an Australian-based electricity retailer that pass through the real-time wholesale price of energy.  Because of Amber's wholesale power prices, you can save hundreds of dollars a year by automating high power devices like air-conditioners, heat pumps and pool pumps.  This Python library provides an interface to the API, allowing you to react to current and forecast prices, as well as download your historic usage.

    The version of the OpenAPI document: 2.0.0
    Contact: dev@amber.com.au
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from amberelectric.models.actual_interval import ActualInterval  # noqa: E501

class TestActualInterval(unittest.TestCase):
    """ActualInterval unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ActualInterval:
        """Test ActualInterval
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ActualInterval`
        """
        model = ActualInterval()  # noqa: E501
        if include_optional:
            return ActualInterval(
                type = 'ActualInterval',
                duration = 5,
                spot_per_kwh = 6.12,
                per_kwh = 24.33,
                var_date = 'Wed May 05 10:00:00 AEST 2021',
                nem_time = '2021-05-06T12:30+10:00',
                start_time = '2021-05-05T02:00:01Z',
                end_time = '2021-05-05T02:30Z',
                renewables = 45,
                channel_type = 'general',
                tariff_information = amberelectric.models.tariff_information.TariffInformation(
                    period = 'offPeak', 
                    season = 'default', 
                    block = 1, 
                    demand_window = True, ),
                spike_status = 'none',
                descriptor = 'negative'
            )
        else:
            return ActualInterval(
                type = 'ActualInterval',
                duration = 5,
                spot_per_kwh = 6.12,
                per_kwh = 24.33,
                var_date = 'Wed May 05 10:00:00 AEST 2021',
                nem_time = '2021-05-06T12:30+10:00',
                start_time = '2021-05-05T02:00:01Z',
                end_time = '2021-05-05T02:30Z',
                renewables = 45,
                channel_type = 'general',
                spike_status = 'none',
                descriptor = 'negative',
        )
        """

    def testActualInterval(self):
        """Test ActualInterval"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



"""API response object."""

from __future__ import annotations
from typing import Any, Dict, Optional

try:
    from pydantic.v1 import Field, StrictInt, StrictStr
except ImportError:
    from pydantic import Field, StrictInt, StrictStr


class ApiResponse:
    """
    API response object
    """

    status_code: Optional[StrictInt] = Field(None, description="HTTP status code")
    headers: Optional[Dict[StrictStr, StrictStr]] = Field(
        None, description="HTTP headers"
    )
    data: Optional[Any] = Field(
        None, description="Deserialized data given the data type"
    )
    raw_data: Optional[Any] = Field(None, description="Raw data (HTTP response body)")

    def __init__(
        self, status_code=None, headers=None, data=None, raw_data=None
    ) -> None:
        self.status_code = status_code
        self.headers = headers
        self.data = data
        self.raw_data = raw_data
